==> django_fluo-0.4a3-py3-none-any.whl: fluo/context_processors.py <==
# Copyright (C) 2007-2017, Raffaele Salmaso <raffaele@salmaso.org>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from django.conf import settings

# media_url & static_url idea is taken from
# http://www.djangosnippets.org/snippets/1754/
MEDIA_URL = {
    True: settings.MEDIA_URL.replace('http://', 'https://'),
    False: settings.MEDIA_URL,
}
STATIC_URL = {
    True: settings.STATIC_URL.replace('http://', 'https://'),
    False: settings.STATIC_URL,
}


def media(request):
    return {
        'MEDIA_URL': MEDIA_URL[request.is_secure()],
    }


def static(request):
    return {
        'STATIC_URL': STATIC_URL[request.is_secure()],
    }

==> django_fluo-0.4.14-py3-none-any.whl: fluo/context_processors.py <==
# Copyright (C) 2007-2020, Raffaele Salmaso <raffaele@salmaso.org>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from django.conf import settings

# media_url & static_url idea is taken from
# http://www.djangosnippets.org/snippets/1754/
MEDIA_URL = {
    True: settings.MEDIA_URL.replace("http://", "https://"),
    False: settings.MEDIA_URL,
}
STATIC_URL = {
    True: settings.STATIC_URL.replace("http://", "https://"),
    False: settings.STATIC_URL,
}


def media(request):
    return {
        "MEDIA_URL": MEDIA_URL[request.is_secure()],
    }


def static(request):
    return {
        "STATIC_URL": STATIC_URL[request.is_secure()],
    }
